@@ -2,11 +2,11 @@ library(testthat)
 library(recipes)
 
 
-ex_tr <- data.frame(x1 = 1:100, 
-                    x2 = rep(1:5, each = 20), 
+ex_tr <- data.frame(x1 = 1:100,
+                    x2 = rep(1:5, each = 20),
                     x3 = factor(rep(letters[1:2], each = 50)))
 ex_te <- data.frame(x1 = c(1, 50, 101, NA))
-                     
+
 lvls_breaks_4 <- c('bin_missing', 'bin1', 'bin2', 'bin3', 'bin4')
 
 test_that('default args', {
@@ -31,9 +31,24 @@ test_that('NA values from out of range', {
 })
 
 
-test_that('printing', {
-  rec <- recipe(~., data = ex_tr) %>% 
+test_that('printing and tidys', {
+  rec <- recipe(~., data = ex_tr) %>%
     step_discretize(x1)
   expect_output(print(rec))
-  expect_output(prep(rec, training = ex_tr))
+  expect_output(prep(rec, training = ex_tr, verbose = TRUE))
+
+  tidy_exp_un <- tibble(
+    terms = "x1",
+    value = NA_real_
+  )
+  expect_equal(tidy(rec, 1), tidy_exp_un)
+
+  rec_trained <- prep(rec, training = ex_tr)
+  br <- rec_trained$steps[[1]]$objects$x1$breaks
+  tidy_exp_tr <- tibble(
+    terms = rep("x1", length(br)),
+    value = br
+  )
+  expect_equal(tidy(rec_trained, 1), tidy_exp_tr)
+
 })
